@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 use parent qw/autobox/;
 
-our $VERSION = "1.028";
+our $VERSION = "1.029";
 
 =head1 NAME
 
@@ -64,6 +64,9 @@ particular when the values are hashrefs or objects.
     # Return array, even in scalar context
     @books->to_array;
 
+    # Turn paired items into a hash
+    @titles_books->to_hash;
+
 
 =head2 Arrays with hashrefs/objects
 
@@ -132,6 +135,7 @@ particular when the values are hashrefs or objects.
 
 =head2 Hashes
 
+    # map over each pair
     # Upper-case the genre name, and make the count say "n books"
     #     (return a key => value pair)
     $genre_count->map_each(sub { uc( $_[0] ) => "$_ books" });
@@ -140,6 +144,7 @@ particular when the values are hashrefs or objects.
     #     "SCI-FI"  => "3 books",
     # },
 
+    # map over each value
     # Make the count say "n books"
     #     (return the new value)
     $genre_count->map_each_value(sub { "$_ books" });
@@ -148,30 +153,38 @@ particular when the values are hashrefs or objects.
     #     "Sci-fi"  => "3 books",
     # },
 
+    # map each pair into an array
     # Transform each pair to the string "n: genre"
     #     (return list of items)
     $genre_count->map_each_to_array(sub { "$_: $_[0]" });
     # [ "1: Fantasy", "3: Sci-fi" ]
 
+    # filter each pair
     # Genres with more than five books
     $genre_count->filter_each(sub { $_ > 5 });
 
     # Return reference, even in list context, e.g. in a parameter list
-    %genre_count->to_ref );
+    %genre_count->to_ref;
 
     # Return hash, even in scalar context
     $author->book_count->to_hash;
 
+    # Turn key-value pairs into an array
+    %isbn__book->to_array;
+
 
 =head2 Combined examples
 
     my $order_authors = $order->books
+        ->filter_by("title", qr/^The/)
         ->uniq_by("isbn")
         ->map_by("author")
-        ->map_by("name")->uniq->sort->join(", ");
+        ->uniq_by("name")
+        ->order_by(publisher => "str", name => "str")
+        ->map_by("name")->uniq->join(", ");
 
     my $total_order_amount = $order->books
-        ->filter_by([ not_covered_by_vouchers => $vouchers ])
+        ->filter_by([ covered_by_vouchers => $vouchers ], sub { ! $_ })
         ->map_by([ price_with_tax => $tax_pct ])
         ->sum;
 
@@ -186,51 +199,55 @@ and hashrefs.
 
 =item
 
-$array->filter()
+@array->filter()
 
 =item
 
-$array->order()
+@array->order()
 
 =item
 
-$array->flat()
+@array->flat()
 
 =item
 
-$array->as_ref()
+@array->to_ref()
 
 =item
 
-$array->as_array()
+@array->to_array()
 
 =item
 
-$array->map_by()
+@array->to_hash()
 
 =item
 
-$array->filter_by()
+@array->map_by()
 
 =item
 
-$array->uniq_by()
+@array->filter_by()
 
 =item
 
-$array->order_by()
+@array->uniq_by()
 
 =item
 
-$array->group_by()
+@array->order_by()
 
 =item
 
-$array->group_by_count()
+@array->group_by()
 
 =item
 
-$array->group_by_array()
+@array->group_by_count()
+
+=item
+
+@array->group_by_array()
 
 =back
 
@@ -239,27 +256,31 @@ $array->group_by_array()
 
 =item
 
-$hash->map_each
+%hash->map_each
 
 =item
 
-$hash->map_each_value
+%hash->map_each_value
 
 =item
 
-$hash->map_each_to_array
+%hash->map_each_to_array
 
 =item
 
-$hash->filter_each
+%hash->filter_each
 
 =item
 
-$array->as_ref()
+%hash->to_ref()
 
 =item
 
-$array->as_hash()
+%hash->to_hash()
+
+=item
+
+%hash->to_array()
 
 =back
 
@@ -633,7 +654,7 @@ The value of join("", @captured_groups) are used in the comparison (@captured_gr
 
 =head3 Examples of fallback comparisons
 
-When the first comparison is a tie, the subsequenc ones are used.
+When the first comparison is a tie, the subsequent ones are used.
 
     # order: list of comparison options (one or an arrayref with many
     # options, per comparison)
@@ -1010,6 +1031,29 @@ sub to_array {
     return @$array;
 }
 
+=head2 @array->to_hash() : %hash | %$hash
+
+Return the item pairs in the @array as the key-value pairs of a %hash
+(context sensitive).
+
+Useful if you need to continue calling %hash methods on it.
+
+Die if there aren't an even number of items in @array.
+
+=cut
+
+sub to_hash {
+    my $array = shift;
+    my $count = @$array;
+
+    $count % 2 and Carp::croak(
+        "\@array->to_hash on an array with an odd number of elements ($count)",
+    );
+
+    my %new_hash = @$array;
+    return wantarray ? %new_hash : \%new_hash;
+}
+
 
 
 =head1 METHODS ON ARRAYS CONTAINING OBJECTS/HASHES
@@ -1068,22 +1112,23 @@ string.
 Call the $accessor on each object in @array, or get the hash key value
 on each hashref in @array. Like:
 
-    map { $_->$accessor() }
+    map { $_->$accessor() } @array
     # or
-    map { $_->{$accessor} }
+    map { $_->{$accessor} } @array
 
 Examples:
 
-    my @ahthor_names = $authors->map_by("name");
-    my $author_names = @publishers->map_by("authors")->map_by("name");
+    my @author_names = $authors->map_by("name");
+    my $author_names = @publishers->map_by("authors")->flat->map_by("name");
 
 Or get the hash key value. Example:
 
     my @review_scores = $reviews->map_by("score");
 
-Alternatively the $accessor is an arrayref. The first item is the
-accessor name, and the rest of the items are passed as args the method
-call. This only works when working with objects, not with hashrefs.
+Alternatively for when @array contains objects, the $accessor can be
+an arrayref. The first item is the method name, and the rest of the
+items are passed as args in the method call. This obviously won't work
+when the @array contains hashrefs.
 
 Examples:
 
@@ -1749,6 +1794,21 @@ sub to_hash {
     return %$hash;
 }
 
+=head2 %hash->to_array() : @array | @$array
+
+Return the key-value pairs of the %hash as an @array, ordered by the
+keys.
+
+Useful if you need to continue calling @array methods on it.
+
+=cut
+
+sub to_array {
+    my $hash = shift;
+    my @new_array = map_each_to_array($hash, sub { shift() => $_ });
+    return wantarray ? @new_array : \@new_array;
+}
+
 
 
 =head1 AUTOBOX AND VANILLA PERL
